# Included Databases

## International Soundscape Database (ISD)

::: soundscapy.databases.isd
    options:
        filters: ["!ISDAccessor", "!_"]

## Soundscape Attributes Translation Project (SATP)

::: soundscapy.databases.satp
